# WEBKNOSSOS REST-API client

:warning: Most code of this client in `_generated` is auto-generated! Please don't adapt anything in the `generated` folder manually, but re-run the code generation, please see [the docs for details](https://docs.webknossos.org/webknossos-py/development.html#webknossos-package).
